# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.device_ranking_response import DeviceRankingResponse  # noqa: E501
from aliro_quantum.rest import ApiException

class TestDeviceRankingResponse(unittest.TestCase):
    """DeviceRankingResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DeviceRankingResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.device_ranking_response.DeviceRankingResponse()  # noqa: E501
        if include_optional :
            return DeviceRankingResponse(
                rankings = [
                    aliro_quantum.models.device_ranking.DeviceRanking(
                        device = aliro_quantum.models.device_details.DeviceDetails(
                            active_reset_fidelity = 1.337, 
                            depth_one_circuit_time = 1.337, 
                            device_id = '0', 
                            display_name = '0', 
                            gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                                averages = {
                                    'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                                        current = 1.337, 
                                        fidelity_change_per_day = 1.337, )
                                    }, 
                                gate_list = [
                                    aliro_quantum.models.gate.Gate(
                                        aliro_computed = True, 
                                        fidelity = 1.337, 
                                        fidelity_change_per_day = 1.337, 
                                        qubit_from = aliro_quantum.models.qubit.Qubit(
                                            name = 56, 
                                            pos_x = 1.337, 
                                            pos_y = 1.337, 
                                            real_qubit = 56, 
                                            t1 = 1.337, 
                                            t2 = 1.337, ), 
                                        qubit_to = aliro_quantum.models.qubit.Qubit(
                                            name = 56, 
                                            pos_x = 1.337, 
                                            pos_y = 1.337, 
                                            real_qubit = 56, 
                                            t1 = 1.337, 
                                            t2 = 1.337, ), 
                                        gate_type = '0', )
                                    ], ), 
                            gates = [
                                aliro_quantum.models.gate.Gate(
                                    aliro_computed = True, 
                                    fidelity = 1.337, 
                                    fidelity_change_per_day = 1.337, 
                                    gate_type = '0', )
                                ], 
                            initialization_time = 1.337, 
                            is_simulator = True, 
                            jobs_queue_size = 56, 
                            last_calibration = '0', 
                            max_shots = 56, 
                            next_available_time = '0', 
                            price = 1.337, 
                            quantum_volume = 56, 
                            qubits = {
                                'key' : aliro_quantum.models.qubit.Qubit(
                                    name = 56, 
                                    pos_x = 1.337, 
                                    pos_y = 1.337, 
                                    real_qubit = 56, 
                                    t1 = 1.337, 
                                    t2 = 1.337, )
                                }, 
                            supports_mid_circuit_measurement = True, 
                            t1 = 1.337, 
                            t2 = 1.337, ), 
                        score = 1.337, )
                    ]
            )
        else :
            return DeviceRankingResponse(
        )

    def testDeviceRankingResponse(self):
        """Test DeviceRankingResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.submission import Submission  # noqa: E501
from aliro_quantum.rest import ApiException

class TestSubmission(unittest.TestCase):
    """Submission unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Submission
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.submission.Submission()  # noqa: E501
        if include_optional :
            return Submission(
                circuits = [
                    aliro_quantum.models.circuit.Circuit(
                        body = '0', 
                        depth = 56, 
                        jobs = [
                            aliro_quantum.models.job.Job(
                                allocations = aliro_quantum.models.job_allocations.Job_allocations(
                                    allocated_circuits = [
                                        aliro_quantum.models.allocation.Allocation(
                                            allocated_qubits = [
                                                56
                                                ], 
                                            depth = 56, 
                                            program = '0', 
                                            num_gates_double = 56, 
                                            num_gates_single = 56, 
                                            num_measurements = 56, 
                                            num_swaps = 56, )
                                        ], 
                                    input_parameters = aliro_quantum.models.compilation_parameters.CompilationParameters(
                                        compilation_type = '0', 
                                        num_allocations = 56, ), 
                                    language = '0', 
                                    runtime = 1.337, ), 
                                cancelling = True, 
                                costs = aliro_quantum.models.job_costs.Job_costs(
                                    reservation = 1.337, ), 
                                errors = [
                                    aliro_quantum.models.job_errors.Job_errors(
                                        error_code = '0', 
                                        error_message = '0', )
                                    ], 
                                execution = aliro_quantum.models.job_execution.Job_execution(
                                    parameters = aliro_quantum.models.execution_parameters.ExecutionParameters(
                                        num_shots = 56, 
                                        output_type = '0', ), 
                                    results = aliro_quantum.models.execution_results.ExecutionResults(
                                        real = aliro_quantum.models.results_data.ResultsData(
                                            empirical_sso = 1.337, 
                                            end_datetime = '0', 
                                            measurements = aliro_quantum.models.results_data_measurements.ResultsData_measurements(
                                                raw = [
                                                    [
                                                        [
                                                            56
                                                            ]
                                                        ]
                                                    ], 
                                                weighted_combination = {
                                                    'key' : 1.337
                                                    }, ), 
                                            runtime = 1.337, 
                                            start_datetime = '0', ), 
                                        simulated = aliro_quantum.models.results_data.ResultsData(
                                            empirical_sso = 1.337, 
                                            end_datetime = '0', 
                                            runtime = 1.337, 
                                            start_datetime = '0', ), ), ), 
                                id = '0', 
                                reservation = aliro_quantum.models.reservation.Reservation(
                                    end_datetime = '0', 
                                    id = '0', 
                                    price = 1.337, 
                                    start_datetime = '0', 
                                    their_id = '0', ), 
                                target = aliro_quantum.models.owner_details.OwnerDetails(
                                    owners = {
                                        'key' : aliro_quantum.models.owner_details_owners.OwnerDetails_owners(
                                            devices = {
                                                'key' : aliro_quantum.models.device_details.DeviceDetails(
                                                    active_reset_fidelity = 1.337, 
                                                    depth_one_circuit_time = 1.337, 
                                                    device_id = '0', 
                                                    display_name = '0', 
                                                    gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                                                        averages = {
                                                            'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                                                                current = 1.337, 
                                                                fidelity_change_per_day = 1.337, )
                                                            }, 
                                                        gate_list = [
                                                            aliro_quantum.models.gate.Gate(
                                                                aliro_computed = True, 
                                                                fidelity = 1.337, 
                                                                fidelity_change_per_day = 1.337, 
                                                                qubit_from = aliro_quantum.models.qubit.Qubit(
                                                                    name = 56, 
                                                                    pos_x = 1.337, 
                                                                    pos_y = 1.337, 
                                                                    real_qubit = 56, 
                                                                    t1 = 1.337, 
                                                                    t2 = 1.337, ), 
                                                                qubit_to = aliro_quantum.models.qubit.Qubit(
                                                                    name = 56, 
                                                                    pos_x = 1.337, 
                                                                    pos_y = 1.337, 
                                                                    real_qubit = 56, 
                                                                    t1 = 1.337, 
                                                                    t2 = 1.337, ), 
                                                                gate_type = '0', )
                                                            ], ), 
                                                    gates = [
                                                        aliro_quantum.models.gate.Gate(
                                                            aliro_computed = True, 
                                                            fidelity = 1.337, 
                                                            fidelity_change_per_day = 1.337, 
                                                            gate_type = '0', )
                                                        ], 
                                                    initialization_time = 1.337, 
                                                    is_simulator = True, 
                                                    jobs_queue_size = 56, 
                                                    last_calibration = '0', 
                                                    max_shots = 56, 
                                                    next_available_time = '0', 
                                                    price = 1.337, 
                                                    quantum_volume = 56, 
                                                    qubits = {
                                                        'key' : aliro_quantum.models.qubit.Qubit(
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, 
                                                            t1 = 1.337, 
                                                            t2 = 1.337, )
                                                        }, 
                                                    supports_mid_circuit_measurement = True, 
                                                    t1 = 1.337, 
                                                    t2 = 1.337, )
                                                }, )
                                        }, ), )
                            ], 
                        language = '0', 
                        name = '0', 
                        num_gates_double = 56, 
                        num_gates_single = 56, 
                        num_measurements = 56, 
                        num_swaps = 56, )
                    ], 
                create_date = '0', 
                name = '0'
            )
        else :
            return Submission(
                circuits = [
                    aliro_quantum.models.circuit.Circuit(
                        body = '0', 
                        depth = 56, 
                        jobs = [
                            aliro_quantum.models.job.Job(
                                allocations = aliro_quantum.models.job_allocations.Job_allocations(
                                    allocated_circuits = [
                                        aliro_quantum.models.allocation.Allocation(
                                            allocated_qubits = [
                                                56
                                                ], 
                                            depth = 56, 
                                            program = '0', 
                                            num_gates_double = 56, 
                                            num_gates_single = 56, 
                                            num_measurements = 56, 
                                            num_swaps = 56, )
                                        ], 
                                    input_parameters = aliro_quantum.models.compilation_parameters.CompilationParameters(
                                        compilation_type = '0', 
                                        num_allocations = 56, ), 
                                    language = '0', 
                                    runtime = 1.337, ), 
                                cancelling = True, 
                                costs = aliro_quantum.models.job_costs.Job_costs(
                                    reservation = 1.337, ), 
                                errors = [
                                    aliro_quantum.models.job_errors.Job_errors(
                                        error_code = '0', 
                                        error_message = '0', )
                                    ], 
                                execution = aliro_quantum.models.job_execution.Job_execution(
                                    parameters = aliro_quantum.models.execution_parameters.ExecutionParameters(
                                        num_shots = 56, 
                                        output_type = '0', ), 
                                    results = aliro_quantum.models.execution_results.ExecutionResults(
                                        real = aliro_quantum.models.results_data.ResultsData(
                                            empirical_sso = 1.337, 
                                            end_datetime = '0', 
                                            measurements = aliro_quantum.models.results_data_measurements.ResultsData_measurements(
                                                raw = [
                                                    [
                                                        [
                                                            56
                                                            ]
                                                        ]
                                                    ], 
                                                weighted_combination = {
                                                    'key' : 1.337
                                                    }, ), 
                                            runtime = 1.337, 
                                            start_datetime = '0', ), 
                                        simulated = aliro_quantum.models.results_data.ResultsData(
                                            empirical_sso = 1.337, 
                                            end_datetime = '0', 
                                            runtime = 1.337, 
                                            start_datetime = '0', ), ), ), 
                                id = '0', 
                                reservation = aliro_quantum.models.reservation.Reservation(
                                    end_datetime = '0', 
                                    id = '0', 
                                    price = 1.337, 
                                    start_datetime = '0', 
                                    their_id = '0', ), 
                                target = aliro_quantum.models.owner_details.OwnerDetails(
                                    owners = {
                                        'key' : aliro_quantum.models.owner_details_owners.OwnerDetails_owners(
                                            devices = {
                                                'key' : aliro_quantum.models.device_details.DeviceDetails(
                                                    active_reset_fidelity = 1.337, 
                                                    depth_one_circuit_time = 1.337, 
                                                    device_id = '0', 
                                                    display_name = '0', 
                                                    gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                                                        averages = {
                                                            'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                                                                current = 1.337, 
                                                                fidelity_change_per_day = 1.337, )
                                                            }, 
                                                        gate_list = [
                                                            aliro_quantum.models.gate.Gate(
                                                                aliro_computed = True, 
                                                                fidelity = 1.337, 
                                                                fidelity_change_per_day = 1.337, 
                                                                qubit_from = aliro_quantum.models.qubit.Qubit(
                                                                    name = 56, 
                                                                    pos_x = 1.337, 
                                                                    pos_y = 1.337, 
                                                                    real_qubit = 56, 
                                                                    t1 = 1.337, 
                                                                    t2 = 1.337, ), 
                                                                qubit_to = aliro_quantum.models.qubit.Qubit(
                                                                    name = 56, 
                                                                    pos_x = 1.337, 
                                                                    pos_y = 1.337, 
                                                                    real_qubit = 56, 
                                                                    t1 = 1.337, 
                                                                    t2 = 1.337, ), 
                                                                gate_type = '0', )
                                                            ], ), 
                                                    gates = [
                                                        aliro_quantum.models.gate.Gate(
                                                            aliro_computed = True, 
                                                            fidelity = 1.337, 
                                                            fidelity_change_per_day = 1.337, 
                                                            gate_type = '0', )
                                                        ], 
                                                    initialization_time = 1.337, 
                                                    is_simulator = True, 
                                                    jobs_queue_size = 56, 
                                                    last_calibration = '0', 
                                                    max_shots = 56, 
                                                    next_available_time = '0', 
                                                    price = 1.337, 
                                                    quantum_volume = 56, 
                                                    qubits = {
                                                        'key' : aliro_quantum.models.qubit.Qubit(
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, 
                                                            t1 = 1.337, 
                                                            t2 = 1.337, )
                                                        }, 
                                                    supports_mid_circuit_measurement = True, 
                                                    t1 = 1.337, 
                                                    t2 = 1.337, )
                                                }, )
                                        }, ), )
                            ], 
                        language = '0', 
                        name = '0', 
                        num_gates_double = 56, 
                        num_gates_single = 56, 
                        num_measurements = 56, 
                        num_swaps = 56, )
                    ],
                name = '0',
        )

    def testSubmission(self):
        """Test Submission"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from aliro_quantum.api_client import ApiClient
from aliro_quantum.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SubmissionsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def submissions_delete(self, delete_submission_parameters, **kwargs):  # noqa: E501
        """delete submissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_delete(delete_submission_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteSubmissionParameters delete_submission_parameters: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BasicSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_delete_with_http_info(delete_submission_parameters, **kwargs)  # noqa: E501

    def submissions_delete_with_http_info(self, delete_submission_parameters, **kwargs):  # noqa: E501
        """delete submissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_delete_with_http_info(delete_submission_parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DeleteSubmissionParameters delete_submission_parameters: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BasicSuccess, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'delete_submission_parameters'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_delete" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'delete_submission_parameters' is set
        if self.api_client.client_side_validation and ('delete_submission_parameters' not in local_var_params or  # noqa: E501
                                                        local_var_params['delete_submission_parameters'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `delete_submission_parameters` when calling `submissions_delete`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'delete_submission_parameters' in local_var_params:
            body_params = local_var_params['delete_submission_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BasicSuccess',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submissions_get(self, **kwargs):  # noqa: E501
        """get all user's submissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str begin_date:
        :param str end_date:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SubmissionSummaryResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_get_with_http_info(**kwargs)  # noqa: E501

    def submissions_get_with_http_info(self, **kwargs):  # noqa: E501
        """get all user's submissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str begin_date:
        :param str end_date:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SubmissionSummaryResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'begin_date',
            'end_date'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'begin_date' in local_var_params and local_var_params['begin_date'] is not None:  # noqa: E501
            query_params.append(('beginDate', local_var_params['begin_date']))  # noqa: E501
        if 'end_date' in local_var_params and local_var_params['end_date'] is not None:  # noqa: E501
            query_params.append(('endDate', local_var_params['end_date']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubmissionSummaryResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submissions_post(self, **kwargs):  # noqa: E501
        """submit a new submission  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Submission submission: Submission must include at least one circuit with a name, language, and body
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BasicSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_post_with_http_info(**kwargs)  # noqa: E501

    def submissions_post_with_http_info(self, **kwargs):  # noqa: E501
        """submit a new submission  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param Submission submission: Submission must include at least one circuit with a name, language, and body
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BasicSuccess, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'submission'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'submission' in local_var_params:
            body_params = local_var_params['submission']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BasicSuccess',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submissions_rename_post(self, **kwargs):  # noqa: E501
        """rename submission  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_rename_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SubmissionRenameParameters submission_rename_parameters:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: BasicSuccess
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_rename_post_with_http_info(**kwargs)  # noqa: E501

    def submissions_rename_post_with_http_info(self, **kwargs):  # noqa: E501
        """rename submission  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_rename_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param SubmissionRenameParameters submission_rename_parameters:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(BasicSuccess, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'submission_rename_parameters'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_rename_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'submission_rename_parameters' in local_var_params:
            body_params = local_var_params['submission_rename_parameters']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['*/*'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions/rename', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BasicSuccess',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submissions_submission_name_get(self, submission_name, **kwargs):  # noqa: E501
        """get submissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_submission_name_get(submission_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str submission_name: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SubmissionDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_submission_name_get_with_http_info(submission_name, **kwargs)  # noqa: E501

    def submissions_submission_name_get_with_http_info(self, submission_name, **kwargs):  # noqa: E501
        """get submissions  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_submission_name_get_with_http_info(submission_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str submission_name: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SubmissionDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'submission_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_submission_name_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'submission_name' is set
        if self.api_client.client_side_validation and ('submission_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['submission_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `submission_name` when calling `submissions_submission_name_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'submission_name' in local_var_params:
            path_params['submissionName'] = local_var_params['submission_name']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions/{submissionName}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubmissionDetailResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submissions_submission_name_stream_get(self, submission_name, **kwargs):  # noqa: E501
        """Stream submission updates. Valid event types to listen for are:   - SUBMISSION_DETAIL_UPDATED   - SUBMISSION_DETAIL_COMPLETED   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_submission_name_stream_get(submission_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str submission_name: (required)
        :param str completion_only:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SubmissionDetailResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_submission_name_stream_get_with_http_info(submission_name, **kwargs)  # noqa: E501

    def submissions_submission_name_stream_get_with_http_info(self, submission_name, **kwargs):  # noqa: E501
        """Stream submission updates. Valid event types to listen for are:   - SUBMISSION_DETAIL_UPDATED   - SUBMISSION_DETAIL_COMPLETED   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_submission_name_stream_get_with_http_info(submission_name, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str submission_name: (required)
        :param str completion_only:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SubmissionDetailResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'submission_name',
            'completion_only'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_submission_name_stream_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'submission_name' is set
        if self.api_client.client_side_validation and ('submission_name' not in local_var_params or  # noqa: E501
                                                        local_var_params['submission_name'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `submission_name` when calling `submissions_submission_name_stream_get`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'submission_name' in local_var_params:
            path_params['submissionName'] = local_var_params['submission_name']  # noqa: E501

        query_params = []
        if 'completion_only' in local_var_params and local_var_params['completion_only'] is not None:  # noqa: E501
            query_params.append(('completionOnly', local_var_params['completion_only']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/event-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions/{submissionName}/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubmissionDetailResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def submissions_summary_stream_get(self, **kwargs):  # noqa: E501
        """Stream submissions summary. Possible event types:    - SUBMISSION_SUMMARY_UPDATED   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_summary_stream_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: SubmissionSummary
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.submissions_summary_stream_get_with_http_info(**kwargs)  # noqa: E501

    def submissions_summary_stream_get_with_http_info(self, **kwargs):  # noqa: E501
        """Stream submissions summary. Possible event types:    - SUBMISSION_SUMMARY_UPDATED   # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.submissions_summary_stream_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(SubmissionSummary, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method submissions_summary_stream_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/event-stream'])  # noqa: E501

        # Authentication setting
        auth_settings = ['JwtKeyAuth']  # noqa: E501

        return self.api_client.call_api(
            '/submissions/summary/stream', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='SubmissionSummary',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class Circuit(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'body': 'str',
        'depth': 'int',
        'jobs': 'list[Job]',
        'language': 'str',
        'name': 'str',
        'num_gates_double': 'int',
        'num_gates_single': 'int',
        'num_measurements': 'int',
        'num_swaps': 'int'
    }

    attribute_map = {
        'body': 'body',
        'depth': 'depth',
        'jobs': 'jobs',
        'language': 'language',
        'name': 'name',
        'num_gates_double': 'numGatesDouble',
        'num_gates_single': 'numGatesSingle',
        'num_measurements': 'numMeasurements',
        'num_swaps': 'numSwaps'
    }

    def __init__(self, body=None, depth=None, jobs=None, language=None, name=None, num_gates_double=None, num_gates_single=None, num_measurements=None, num_swaps=None, local_vars_configuration=None):  # noqa: E501
        """Circuit - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._body = None
        self._depth = None
        self._jobs = None
        self._language = None
        self._name = None
        self._num_gates_double = None
        self._num_gates_single = None
        self._num_measurements = None
        self._num_swaps = None
        self.discriminator = None

        self.body = body
        if depth is not None:
            self.depth = depth
        self.jobs = jobs
        self.language = language
        if name is not None:
            self.name = name
        if num_gates_double is not None:
            self.num_gates_double = num_gates_double
        if num_gates_single is not None:
            self.num_gates_single = num_gates_single
        if num_measurements is not None:
            self.num_measurements = num_measurements
        if num_swaps is not None:
            self.num_swaps = num_swaps

    @property
    def body(self):
        """Gets the body of this Circuit.  # noqa: E501

        The inputted circuit string  # noqa: E501

        :return: The body of this Circuit.  # noqa: E501
        :rtype: str
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this Circuit.

        The inputted circuit string  # noqa: E501

        :param body: The body of this Circuit.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and body is None:  # noqa: E501
            raise ValueError("Invalid value for `body`, must not be `None`")  # noqa: E501

        self._body = body

    @property
    def depth(self):
        """Gets the depth of this Circuit.  # noqa: E501


        :return: The depth of this Circuit.  # noqa: E501
        :rtype: int
        """
        return self._depth

    @depth.setter
    def depth(self, depth):
        """Sets the depth of this Circuit.


        :param depth: The depth of this Circuit.  # noqa: E501
        :type: int
        """

        self._depth = depth

    @property
    def jobs(self):
        """Gets the jobs of this Circuit.  # noqa: E501


        :return: The jobs of this Circuit.  # noqa: E501
        :rtype: list[Job]
        """
        return self._jobs

    @jobs.setter
    def jobs(self, jobs):
        """Sets the jobs of this Circuit.


        :param jobs: The jobs of this Circuit.  # noqa: E501
        :type: list[Job]
        """
        if self.local_vars_configuration.client_side_validation and jobs is None:  # noqa: E501
            raise ValueError("Invalid value for `jobs`, must not be `None`")  # noqa: E501

        self._jobs = jobs

    @property
    def language(self):
        """Gets the language of this Circuit.  # noqa: E501


        :return: The language of this Circuit.  # noqa: E501
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Circuit.


        :param language: The language of this Circuit.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and language is None:  # noqa: E501
            raise ValueError("Invalid value for `language`, must not be `None`")  # noqa: E501

        self._language = language

    @property
    def name(self):
        """Gets the name of this Circuit.  # noqa: E501


        :return: The name of this Circuit.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Circuit.


        :param name: The name of this Circuit.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def num_gates_double(self):
        """Gets the num_gates_double of this Circuit.  # noqa: E501


        :return: The num_gates_double of this Circuit.  # noqa: E501
        :rtype: int
        """
        return self._num_gates_double

    @num_gates_double.setter
    def num_gates_double(self, num_gates_double):
        """Sets the num_gates_double of this Circuit.


        :param num_gates_double: The num_gates_double of this Circuit.  # noqa: E501
        :type: int
        """

        self._num_gates_double = num_gates_double

    @property
    def num_gates_single(self):
        """Gets the num_gates_single of this Circuit.  # noqa: E501


        :return: The num_gates_single of this Circuit.  # noqa: E501
        :rtype: int
        """
        return self._num_gates_single

    @num_gates_single.setter
    def num_gates_single(self, num_gates_single):
        """Sets the num_gates_single of this Circuit.


        :param num_gates_single: The num_gates_single of this Circuit.  # noqa: E501
        :type: int
        """

        self._num_gates_single = num_gates_single

    @property
    def num_measurements(self):
        """Gets the num_measurements of this Circuit.  # noqa: E501


        :return: The num_measurements of this Circuit.  # noqa: E501
        :rtype: int
        """
        return self._num_measurements

    @num_measurements.setter
    def num_measurements(self, num_measurements):
        """Sets the num_measurements of this Circuit.


        :param num_measurements: The num_measurements of this Circuit.  # noqa: E501
        :type: int
        """

        self._num_measurements = num_measurements

    @property
    def num_swaps(self):
        """Gets the num_swaps of this Circuit.  # noqa: E501


        :return: The num_swaps of this Circuit.  # noqa: E501
        :rtype: int
        """
        return self._num_swaps

    @num_swaps.setter
    def num_swaps(self, num_swaps):
        """Sets the num_swaps of this Circuit.


        :param num_swaps: The num_swaps of this Circuit.  # noqa: E501
        :type: int
        """

        self._num_swaps = num_swaps

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Circuit):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Circuit):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.results_data import ResultsData  # noqa: E501
from aliro_quantum.rest import ApiException

class TestResultsData(unittest.TestCase):
    """ResultsData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ResultsData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.results_data.ResultsData()  # noqa: E501
        if include_optional :
            return ResultsData(
                empirical_sso = 1.337, 
                end_datetime = '0', 
                measurements = aliro_quantum.models.results_data_measurements.ResultsData_measurements(
                    raw = [
                        [
                            [
                                56
                                ]
                            ]
                        ], 
                    weighted_combination = {
                        'key' : 1.337
                        }, ), 
                runtime = 1.337, 
                start_datetime = '0'
            )
        else :
            return ResultsData(
        )

    def testResultsData(self):
        """Test ResultsData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.authentication_api import AuthenticationApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestAuthenticationApi(unittest.TestCase):
    """AuthenticationApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.authentication_api.AuthenticationApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_auth_login_post(self):
        """Test case for auth_login_post

        login using username and password  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from aliro_quantum.models.allocation import Allocation
from aliro_quantum.models.api_key import ApiKey
from aliro_quantum.models.api_key_response import ApiKeyResponse
from aliro_quantum.models.basic_success import BasicSuccess
from aliro_quantum.models.change_password_parameters import ChangePasswordParameters
from aliro_quantum.models.circuit import Circuit
from aliro_quantum.models.compilation_parameters import CompilationParameters
from aliro_quantum.models.control_flow_graph_circuit import ControlFlowGraphCircuit
from aliro_quantum.models.credentials_add_parameters import CredentialsAddParameters
from aliro_quantum.models.credentials_aqt import CredentialsAqt
from aliro_quantum.models.credentials_basic import CredentialsBasic
from aliro_quantum.models.credentials_delete_parameters import CredentialsDeleteParameters
from aliro_quantum.models.credentials_honeywell import CredentialsHoneywell
from aliro_quantum.models.credentials_ibm import CredentialsIbm
from aliro_quantum.models.credentials_ibm_provider import CredentialsIbmProvider
from aliro_quantum.models.credentials_rigetti import CredentialsRigetti
from aliro_quantum.models.credentials_vendor import CredentialsVendor
from aliro_quantum.models.delete_submission_parameters import DeleteSubmissionParameters
from aliro_quantum.models.device_details import DeviceDetails
from aliro_quantum.models.device_details_gate_info import DeviceDetailsGateInfo
from aliro_quantum.models.device_details_gate_info_averages import DeviceDetailsGateInfoAverages
from aliro_quantum.models.device_list_response import DeviceListResponse
from aliro_quantum.models.device_ranking import DeviceRanking
from aliro_quantum.models.device_ranking_response import DeviceRankingResponse
from aliro_quantum.models.device_rankings_parameters import DeviceRankingsParameters
from aliro_quantum.models.device_vendor_response import DeviceVendorResponse
from aliro_quantum.models.execution_parameters import ExecutionParameters
from aliro_quantum.models.execution_results import ExecutionResults
from aliro_quantum.models.gate import Gate
from aliro_quantum.models.info_get_response import InfoGetResponse
from aliro_quantum.models.info_get_response_data import InfoGetResponseData
from aliro_quantum.models.job import Job
from aliro_quantum.models.job_allocations import JobAllocations
from aliro_quantum.models.job_costs import JobCosts
from aliro_quantum.models.job_errors import JobErrors
from aliro_quantum.models.job_execution import JobExecution
from aliro_quantum.models.login_response import LoginResponse
from aliro_quantum.models.owner_details import OwnerDetails
from aliro_quantum.models.owner_details_owners import OwnerDetailsOwners
from aliro_quantum.models.pid_response import PidResponse
from aliro_quantum.models.qubit import Qubit
from aliro_quantum.models.reservation import Reservation
from aliro_quantum.models.results_data import ResultsData
from aliro_quantum.models.results_data_measurements import ResultsDataMeasurements
from aliro_quantum.models.submission import Submission
from aliro_quantum.models.submission_detail_response import SubmissionDetailResponse
from aliro_quantum.models.submission_rename_parameters import SubmissionRenameParameters
from aliro_quantum.models.submission_summary import SubmissionSummary
from aliro_quantum.models.submission_summary_jobs import SubmissionSummaryJobs
from aliro_quantum.models.submission_summary_response import SubmissionSummaryResponse
from aliro_quantum.models.translation_parameters import TranslationParameters
from aliro_quantum.models.translation_response import TranslationResponse
from aliro_quantum.models.update_user_information_parameters import UpdateUserInformationParameters
from aliro_quantum.models.user_info import UserInfo
from aliro_quantum.models.visualization_response import VisualizationResponse



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.owner_details import OwnerDetails  # noqa: E501
from aliro_quantum.rest import ApiException

class TestOwnerDetails(unittest.TestCase):
    """OwnerDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test OwnerDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.owner_details.OwnerDetails()  # noqa: E501
        if include_optional :
            return OwnerDetails(
                owners = {
                    'key' : aliro_quantum.models.owner_details_owners.OwnerDetails_owners(
                        devices = {
                            'key' : aliro_quantum.models.device_details.DeviceDetails(
                                active_reset_fidelity = 1.337, 
                                depth_one_circuit_time = 1.337, 
                                device_id = '0', 
                                display_name = '0', 
                                gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                                    averages = {
                                        'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                                            current = 1.337, 
                                            fidelity_change_per_day = 1.337, )
                                        }, 
                                    gate_list = [
                                        aliro_quantum.models.gate.Gate(
                                            aliro_computed = True, 
                                            fidelity = 1.337, 
                                            fidelity_change_per_day = 1.337, 
                                            qubit_from = aliro_quantum.models.qubit.Qubit(
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, 
                                                t1 = 1.337, 
                                                t2 = 1.337, ), 
                                            qubit_to = aliro_quantum.models.qubit.Qubit(
                                                name = 56, 
                                                pos_x = 1.337, 
                                                pos_y = 1.337, 
                                                real_qubit = 56, 
                                                t1 = 1.337, 
                                                t2 = 1.337, ), 
                                            gate_type = '0', )
                                        ], ), 
                                gates = [
                                    aliro_quantum.models.gate.Gate(
                                        aliro_computed = True, 
                                        fidelity = 1.337, 
                                        fidelity_change_per_day = 1.337, 
                                        gate_type = '0', )
                                    ], 
                                initialization_time = 1.337, 
                                is_simulator = True, 
                                jobs_queue_size = 56, 
                                last_calibration = '0', 
                                max_shots = 56, 
                                next_available_time = '0', 
                                price = 1.337, 
                                quantum_volume = 56, 
                                qubits = {
                                    'key' : aliro_quantum.models.qubit.Qubit(
                                        name = 56, 
                                        pos_x = 1.337, 
                                        pos_y = 1.337, 
                                        real_qubit = 56, 
                                        t1 = 1.337, 
                                        t2 = 1.337, )
                                    }, 
                                supports_mid_circuit_measurement = True, 
                                t1 = 1.337, 
                                t2 = 1.337, )
                            }, )
                    }
            )
        else :
            return OwnerDetails(
        )

    def testOwnerDetails(self):
        """Test OwnerDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.device_details_gate_info import DeviceDetailsGateInfo  # noqa: E501
from aliro_quantum.rest import ApiException

class TestDeviceDetailsGateInfo(unittest.TestCase):
    """DeviceDetailsGateInfo unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DeviceDetailsGateInfo
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.device_details_gate_info.DeviceDetailsGateInfo()  # noqa: E501
        if include_optional :
            return DeviceDetailsGateInfo(
                averages = {
                    'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                        current = 1.337, 
                        fidelity_change_per_day = 1.337, )
                    }, 
                gate_list = [
                    aliro_quantum.models.gate.Gate(
                        aliro_computed = True, 
                        fidelity = 1.337, 
                        fidelity_change_per_day = 1.337, 
                        qubit_from = aliro_quantum.models.qubit.Qubit(
                            name = 56, 
                            pos_x = 1.337, 
                            pos_y = 1.337, 
                            real_qubit = 56, 
                            t1 = 1.337, 
                            t2 = 1.337, ), 
                        qubit_to = aliro_quantum.models.qubit.Qubit(
                            name = 56, 
                            pos_x = 1.337, 
                            pos_y = 1.337, 
                            real_qubit = 56, 
                            t1 = 1.337, 
                            t2 = 1.337, ), 
                        gate_type = '0', )
                    ]
            )
        else :
            return DeviceDetailsGateInfo(
        )

    def testDeviceDetailsGateInfo(self):
        """Test DeviceDetailsGateInfo"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.submission_detail_response import SubmissionDetailResponse  # noqa: E501
from aliro_quantum.rest import ApiException

class TestSubmissionDetailResponse(unittest.TestCase):
    """SubmissionDetailResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionDetailResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.submission_detail_response.SubmissionDetailResponse()  # noqa: E501
        if include_optional :
            return SubmissionDetailResponse(
                submission_detail = {
  "circuits": [
    {
      "jobs": [
        {
          "allocations": {
            "inputParameters": {
              "compilationType": "fast",
              "numAllocations": 2
            }
          },
          "execution": {
            "parameters": {
              "numShots": 2,
              "timeout": 7.061401241503109
            }
          },
          "target": {
            "deviceName": "9q-square-qvm",
            "owner": "Rigetti"
          }
        }
      ],
      "language": "quil",
      "name": "quilTestCircuit",
      "body": "CNOT 0 1\nCNOT 0 1\nCNOT 1 0\nCNOT 1 2\nCNOT 2 3\nCNOT 4 3"
    }
  ],
  "createDate": "2020-03-03T15:01:57.687Z",
  "name": "quilTest"
}
, 
                submission_summary = aliro_quantum.models.submission_summary.SubmissionSummary(
                    completed_datetime = '0', 
                    jobs = aliro_quantum.models.submission_summary_jobs.SubmissionSummary_jobs(
                        cancelled = [
                            '0'
                            ], 
                        completed = [
                            '0'
                            ], 
                        error = [
                            '0'
                            ], 
                        initiated = [
                            '0'
                            ], 
                        in_progress = [
                            '0'
                            ], ), 
                    name = '0', 
                    runtime = 1.337, 
                    submitted_datetime = '0', )
            )
        else :
            return SubmissionDetailResponse(
        )

    def testSubmissionDetailResponse(self):
        """Test SubmissionDetailResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.circuit_api import CircuitApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestCircuitApi(unittest.TestCase):
    """CircuitApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.circuit_api.CircuitApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_circuit_translation_post(self):
        """Test case for circuit_translation_post

        translates circuits into other quantum languages  # noqa: E501
        """
        pass

    def test_circuit_visualization_get(self):
        """Test case for circuit_visualization_get

        """
        pass

    def test_circuit_visualization_post(self):
        """Test case for circuit_visualization_post

        converts a Quil circuit into a PNG image  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.submissions_api import SubmissionsApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestSubmissionsApi(unittest.TestCase):
    """SubmissionsApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.submissions_api.SubmissionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_submissions_delete(self):
        """Test case for submissions_delete

        delete submissions  # noqa: E501
        """
        pass

    def test_submissions_get(self):
        """Test case for submissions_get

        get all user's submissions  # noqa: E501
        """
        pass

    def test_submissions_post(self):
        """Test case for submissions_post

        submit a new submission  # noqa: E501
        """
        pass

    def test_submissions_rename_post(self):
        """Test case for submissions_rename_post

        rename submission  # noqa: E501
        """
        pass

    def test_submissions_submission_name_get(self):
        """Test case for submissions_submission_name_get

        get submissions  # noqa: E501
        """
        pass

    def test_submissions_submission_name_stream_get(self):
        """Test case for submissions_submission_name_stream_get

        Stream submission updates. Valid event types to listen for are:   - SUBMISSION_DETAIL_UPDATED   - SUBMISSION_DETAIL_COMPLETED   # noqa: E501
        """
        pass

    def test_submissions_summary_stream_get(self):
        """Test case for submissions_summary_stream_get

        Stream submissions summary. Possible event types:    - SUBMISSION_SUMMARY_UPDATED   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.submission_summary_response import SubmissionSummaryResponse  # noqa: E501
from aliro_quantum.rest import ApiException

class TestSubmissionSummaryResponse(unittest.TestCase):
    """SubmissionSummaryResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SubmissionSummaryResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.submission_summary_response.SubmissionSummaryResponse()  # noqa: E501
        if include_optional :
            return SubmissionSummaryResponse(
                data = [
                    aliro_quantum.models.submission_summary.SubmissionSummary(
                        completed_datetime = '0', 
                        jobs = aliro_quantum.models.submission_summary_jobs.SubmissionSummary_jobs(
                            cancelled = [
                                '0'
                                ], 
                            completed = [
                                '0'
                                ], 
                            error = [
                                '0'
                                ], 
                            initiated = [
                                '0'
                                ], 
                            in_progress = [
                                '0'
                                ], ), 
                        name = '0', 
                        runtime = 1.337, 
                        submitted_datetime = '0', )
                    ]
            )
        else :
            return SubmissionSummaryResponse(
        )

    def testSubmissionSummaryResponse(self):
        """Test SubmissionSummaryResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.device_details import DeviceDetails  # noqa: E501
from aliro_quantum.rest import ApiException

class TestDeviceDetails(unittest.TestCase):
    """DeviceDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test DeviceDetails
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.device_details.DeviceDetails()  # noqa: E501
        if include_optional :
            return DeviceDetails(
                active_reset_fidelity = 1.337, 
                depth_one_circuit_time = 1.337, 
                device_id = '0', 
                display_name = '0', 
                gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                    averages = {
                        'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                            current = 1.337, 
                            fidelity_change_per_day = 1.337, )
                        }, 
                    gate_list = [
                        aliro_quantum.models.gate.Gate(
                            aliro_computed = True, 
                            fidelity = 1.337, 
                            fidelity_change_per_day = 1.337, 
                            qubit_from = aliro_quantum.models.qubit.Qubit(
                                name = 56, 
                                pos_x = 1.337, 
                                pos_y = 1.337, 
                                real_qubit = 56, 
                                t1 = 1.337, 
                                t2 = 1.337, ), 
                            qubit_to = aliro_quantum.models.qubit.Qubit(
                                name = 56, 
                                pos_x = 1.337, 
                                pos_y = 1.337, 
                                real_qubit = 56, 
                                t1 = 1.337, 
                                t2 = 1.337, ), 
                            gate_type = '0', )
                        ], ), 
                gates = [
                    aliro_quantum.models.gate.Gate(
                        aliro_computed = True, 
                        fidelity = 1.337, 
                        fidelity_change_per_day = 1.337, 
                        qubit_from = aliro_quantum.models.qubit.Qubit(
                            name = 56, 
                            pos_x = 1.337, 
                            pos_y = 1.337, 
                            real_qubit = 56, 
                            t1 = 1.337, 
                            t2 = 1.337, ), 
                        qubit_to = aliro_quantum.models.qubit.Qubit(
                            name = 56, 
                            pos_x = 1.337, 
                            pos_y = 1.337, 
                            real_qubit = 56, 
                            t1 = 1.337, 
                            t2 = 1.337, ), 
                        gate_type = '0', )
                    ], 
                initialization_time = 1.337, 
                is_simulator = True, 
                jobs_queue_size = 56, 
                last_calibration = '0', 
                max_shots = 56, 
                next_available_time = '0', 
                price = 1.337, 
                quantum_volume = 56, 
                qubits = {
                    'key' : aliro_quantum.models.qubit.Qubit(
                        name = 56, 
                        pos_x = 1.337, 
                        pos_y = 1.337, 
                        real_qubit = 56, 
                        t1 = 1.337, 
                        t2 = 1.337, )
                    }, 
                supports_mid_circuit_measurement = True, 
                t1 = 1.337, 
                t2 = 1.337
            )
        else :
            return DeviceDetails(
        )

    def testDeviceDetails(self):
        """Test DeviceDetails"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class Job(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'allocations': 'JobAllocations',
        'cancelling': 'bool',
        'costs': 'JobCosts',
        'errors': 'list[JobErrors]',
        'execution': 'JobExecution',
        'id': 'str',
        'reservation': 'Reservation',
        'target': 'OwnerDetails'
    }

    attribute_map = {
        'allocations': 'allocations',
        'cancelling': 'cancelling',
        'costs': 'costs',
        'errors': 'errors',
        'execution': 'execution',
        'id': 'id',
        'reservation': 'reservation',
        'target': 'target'
    }

    def __init__(self, allocations=None, cancelling=None, costs=None, errors=None, execution=None, id=None, reservation=None, target=None, local_vars_configuration=None):  # noqa: E501
        """Job - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._allocations = None
        self._cancelling = None
        self._costs = None
        self._errors = None
        self._execution = None
        self._id = None
        self._reservation = None
        self._target = None
        self.discriminator = None

        self.allocations = allocations
        if cancelling is not None:
            self.cancelling = cancelling
        if costs is not None:
            self.costs = costs
        if errors is not None:
            self.errors = errors
        self.execution = execution
        if id is not None:
            self.id = id
        if reservation is not None:
            self.reservation = reservation
        self.target = target

    @property
    def allocations(self):
        """Gets the allocations of this Job.  # noqa: E501


        :return: The allocations of this Job.  # noqa: E501
        :rtype: JobAllocations
        """
        return self._allocations

    @allocations.setter
    def allocations(self, allocations):
        """Sets the allocations of this Job.


        :param allocations: The allocations of this Job.  # noqa: E501
        :type: JobAllocations
        """
        if self.local_vars_configuration.client_side_validation and allocations is None:  # noqa: E501
            raise ValueError("Invalid value for `allocations`, must not be `None`")  # noqa: E501

        self._allocations = allocations

    @property
    def cancelling(self):
        """Gets the cancelling of this Job.  # noqa: E501


        :return: The cancelling of this Job.  # noqa: E501
        :rtype: bool
        """
        return self._cancelling

    @cancelling.setter
    def cancelling(self, cancelling):
        """Sets the cancelling of this Job.


        :param cancelling: The cancelling of this Job.  # noqa: E501
        :type: bool
        """

        self._cancelling = cancelling

    @property
    def costs(self):
        """Gets the costs of this Job.  # noqa: E501


        :return: The costs of this Job.  # noqa: E501
        :rtype: JobCosts
        """
        return self._costs

    @costs.setter
    def costs(self, costs):
        """Sets the costs of this Job.


        :param costs: The costs of this Job.  # noqa: E501
        :type: JobCosts
        """

        self._costs = costs

    @property
    def errors(self):
        """Gets the errors of this Job.  # noqa: E501


        :return: The errors of this Job.  # noqa: E501
        :rtype: list[JobErrors]
        """
        return self._errors

    @errors.setter
    def errors(self, errors):
        """Sets the errors of this Job.


        :param errors: The errors of this Job.  # noqa: E501
        :type: list[JobErrors]
        """

        self._errors = errors

    @property
    def execution(self):
        """Gets the execution of this Job.  # noqa: E501


        :return: The execution of this Job.  # noqa: E501
        :rtype: JobExecution
        """
        return self._execution

    @execution.setter
    def execution(self, execution):
        """Sets the execution of this Job.


        :param execution: The execution of this Job.  # noqa: E501
        :type: JobExecution
        """
        if self.local_vars_configuration.client_side_validation and execution is None:  # noqa: E501
            raise ValueError("Invalid value for `execution`, must not be `None`")  # noqa: E501

        self._execution = execution

    @property
    def id(self):
        """Gets the id of this Job.  # noqa: E501


        :return: The id of this Job.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Job.


        :param id: The id of this Job.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def reservation(self):
        """Gets the reservation of this Job.  # noqa: E501


        :return: The reservation of this Job.  # noqa: E501
        :rtype: Reservation
        """
        return self._reservation

    @reservation.setter
    def reservation(self, reservation):
        """Sets the reservation of this Job.


        :param reservation: The reservation of this Job.  # noqa: E501
        :type: Reservation
        """

        self._reservation = reservation

    @property
    def target(self):
        """Gets the target of this Job.  # noqa: E501


        :return: The target of this Job.  # noqa: E501
        :rtype: OwnerDetails
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this Job.


        :param target: The target of this Job.  # noqa: E501
        :type: OwnerDetails
        """
        if self.local_vars_configuration.client_side_validation and target is None:  # noqa: E501
            raise ValueError("Invalid value for `target`, must not be `None`")  # noqa: E501

        self._target = target

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Job):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Job):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.job_allocations import JobAllocations  # noqa: E501
from aliro_quantum.rest import ApiException

class TestJobAllocations(unittest.TestCase):
    """JobAllocations unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobAllocations
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.job_allocations.JobAllocations()  # noqa: E501
        if include_optional :
            return JobAllocations(
                allocated_circuits = [
                    aliro_quantum.models.allocation.Allocation(
                        allocated_qubits = [
                            56
                            ], 
                        depth = 56, 
                        program = '0', 
                        num_gates_double = 56, 
                        num_gates_single = 56, 
                        num_measurements = 56, 
                        num_swaps = 56, )
                    ], 
                input_parameters = aliro_quantum.models.compilation_parameters.CompilationParameters(
                    compilation_type = '0', 
                    num_allocations = 56, ), 
                language = '0', 
                runtime = 1.337
            )
        else :
            return JobAllocations(
                input_parameters = aliro_quantum.models.compilation_parameters.CompilationParameters(
                    compilation_type = '0', 
                    num_allocations = 56, ),
        )

    def testJobAllocations(self):
        """Test JobAllocations"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class Reservation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'end_datetime': 'str',
        'id': 'str',
        'price': 'float',
        'start_datetime': 'str',
        'their_id': 'str'
    }

    attribute_map = {
        'end_datetime': 'endDatetime',
        'id': 'id',
        'price': 'price',
        'start_datetime': 'startDatetime',
        'their_id': 'theirId'
    }

    def __init__(self, end_datetime=None, id=None, price=None, start_datetime=None, their_id=None, local_vars_configuration=None):  # noqa: E501
        """Reservation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._end_datetime = None
        self._id = None
        self._price = None
        self._start_datetime = None
        self._their_id = None
        self.discriminator = None

        if end_datetime is not None:
            self.end_datetime = end_datetime
        if id is not None:
            self.id = id
        if price is not None:
            self.price = price
        if start_datetime is not None:
            self.start_datetime = start_datetime
        if their_id is not None:
            self.their_id = their_id

    @property
    def end_datetime(self):
        """Gets the end_datetime of this Reservation.  # noqa: E501


        :return: The end_datetime of this Reservation.  # noqa: E501
        :rtype: str
        """
        return self._end_datetime

    @end_datetime.setter
    def end_datetime(self, end_datetime):
        """Sets the end_datetime of this Reservation.


        :param end_datetime: The end_datetime of this Reservation.  # noqa: E501
        :type: str
        """

        self._end_datetime = end_datetime

    @property
    def id(self):
        """Gets the id of this Reservation.  # noqa: E501


        :return: The id of this Reservation.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Reservation.


        :param id: The id of this Reservation.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def price(self):
        """Gets the price of this Reservation.  # noqa: E501


        :return: The price of this Reservation.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this Reservation.


        :param price: The price of this Reservation.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def start_datetime(self):
        """Gets the start_datetime of this Reservation.  # noqa: E501


        :return: The start_datetime of this Reservation.  # noqa: E501
        :rtype: str
        """
        return self._start_datetime

    @start_datetime.setter
    def start_datetime(self, start_datetime):
        """Sets the start_datetime of this Reservation.


        :param start_datetime: The start_datetime of this Reservation.  # noqa: E501
        :type: str
        """

        self._start_datetime = start_datetime

    @property
    def their_id(self):
        """Gets the their_id of this Reservation.  # noqa: E501


        :return: The their_id of this Reservation.  # noqa: E501
        :rtype: str
        """
        return self._their_id

    @their_id.setter
    def their_id(self, their_id):
        """Sets the their_id of this Reservation.


        :param their_id: The their_id of this Reservation.  # noqa: E501
        :type: str
        """

        self._their_id = their_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Reservation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Reservation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.circuit import Circuit  # noqa: E501
from aliro_quantum.rest import ApiException

class TestCircuit(unittest.TestCase):
    """Circuit unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Circuit
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.circuit.Circuit()  # noqa: E501
        if include_optional :
            return Circuit(
                body = '0', 
                depth = 56, 
                jobs = [
                    aliro_quantum.models.job.Job(
                        allocations = aliro_quantum.models.job_allocations.Job_allocations(
                            allocated_circuits = [
                                aliro_quantum.models.allocation.Allocation(
                                    allocated_qubits = [
                                        56
                                        ], 
                                    depth = 56, 
                                    program = '0', 
                                    num_gates_double = 56, 
                                    num_gates_single = 56, 
                                    num_measurements = 56, 
                                    num_swaps = 56, )
                                ], 
                            input_parameters = aliro_quantum.models.compilation_parameters.CompilationParameters(
                                compilation_type = '0', 
                                num_allocations = 56, ), 
                            language = '0', 
                            runtime = 1.337, ), 
                        cancelling = True, 
                        costs = aliro_quantum.models.job_costs.Job_costs(
                            reservation = 1.337, ), 
                        errors = [
                            aliro_quantum.models.job_errors.Job_errors(
                                error_code = '0', 
                                error_message = '0', )
                            ], 
                        execution = aliro_quantum.models.job_execution.Job_execution(
                            parameters = aliro_quantum.models.execution_parameters.ExecutionParameters(
                                num_shots = 56, 
                                output_type = '0', ), 
                            results = aliro_quantum.models.execution_results.ExecutionResults(
                                real = aliro_quantum.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    measurements = aliro_quantum.models.results_data_measurements.ResultsData_measurements(
                                        raw = [
                                            [
                                                [
                                                    56
                                                    ]
                                                ]
                                            ], 
                                        weighted_combination = {
                                            'key' : 1.337
                                            }, ), 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), 
                                simulated = aliro_quantum.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), ), ), 
                        id = '0', 
                        reservation = aliro_quantum.models.reservation.Reservation(
                            end_datetime = '0', 
                            id = '0', 
                            price = 1.337, 
                            start_datetime = '0', 
                            their_id = '0', ), 
                        target = aliro_quantum.models.owner_details.OwnerDetails(
                            owners = {
                                'key' : aliro_quantum.models.owner_details_owners.OwnerDetails_owners(
                                    devices = {
                                        'key' : aliro_quantum.models.device_details.DeviceDetails(
                                            active_reset_fidelity = 1.337, 
                                            depth_one_circuit_time = 1.337, 
                                            device_id = '0', 
                                            display_name = '0', 
                                            gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                                                averages = {
                                                    'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                                                        current = 1.337, 
                                                        fidelity_change_per_day = 1.337, )
                                                    }, 
                                                gate_list = [
                                                    aliro_quantum.models.gate.Gate(
                                                        aliro_computed = True, 
                                                        fidelity = 1.337, 
                                                        fidelity_change_per_day = 1.337, 
                                                        qubit_from = aliro_quantum.models.qubit.Qubit(
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, 
                                                            t1 = 1.337, 
                                                            t2 = 1.337, ), 
                                                        qubit_to = aliro_quantum.models.qubit.Qubit(
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, 
                                                            t1 = 1.337, 
                                                            t2 = 1.337, ), 
                                                        gate_type = '0', )
                                                    ], ), 
                                            gates = [
                                                aliro_quantum.models.gate.Gate(
                                                    aliro_computed = True, 
                                                    fidelity = 1.337, 
                                                    fidelity_change_per_day = 1.337, 
                                                    gate_type = '0', )
                                                ], 
                                            initialization_time = 1.337, 
                                            is_simulator = True, 
                                            jobs_queue_size = 56, 
                                            last_calibration = '0', 
                                            max_shots = 56, 
                                            next_available_time = '0', 
                                            price = 1.337, 
                                            quantum_volume = 56, 
                                            qubits = {
                                                'key' : aliro_quantum.models.qubit.Qubit(
                                                    name = 56, 
                                                    pos_x = 1.337, 
                                                    pos_y = 1.337, 
                                                    real_qubit = 56, 
                                                    t1 = 1.337, 
                                                    t2 = 1.337, )
                                                }, 
                                            supports_mid_circuit_measurement = True, 
                                            t1 = 1.337, 
                                            t2 = 1.337, )
                                        }, )
                                }, ), )
                    ], 
                language = '0', 
                name = '0', 
                num_gates_double = 56, 
                num_gates_single = 56, 
                num_measurements = 56, 
                num_swaps = 56
            )
        else :
            return Circuit(
                body = '0',
                jobs = [
                    aliro_quantum.models.job.Job(
                        allocations = aliro_quantum.models.job_allocations.Job_allocations(
                            allocated_circuits = [
                                aliro_quantum.models.allocation.Allocation(
                                    allocated_qubits = [
                                        56
                                        ], 
                                    depth = 56, 
                                    program = '0', 
                                    num_gates_double = 56, 
                                    num_gates_single = 56, 
                                    num_measurements = 56, 
                                    num_swaps = 56, )
                                ], 
                            input_parameters = aliro_quantum.models.compilation_parameters.CompilationParameters(
                                compilation_type = '0', 
                                num_allocations = 56, ), 
                            language = '0', 
                            runtime = 1.337, ), 
                        cancelling = True, 
                        costs = aliro_quantum.models.job_costs.Job_costs(
                            reservation = 1.337, ), 
                        errors = [
                            aliro_quantum.models.job_errors.Job_errors(
                                error_code = '0', 
                                error_message = '0', )
                            ], 
                        execution = aliro_quantum.models.job_execution.Job_execution(
                            parameters = aliro_quantum.models.execution_parameters.ExecutionParameters(
                                num_shots = 56, 
                                output_type = '0', ), 
                            results = aliro_quantum.models.execution_results.ExecutionResults(
                                real = aliro_quantum.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    measurements = aliro_quantum.models.results_data_measurements.ResultsData_measurements(
                                        raw = [
                                            [
                                                [
                                                    56
                                                    ]
                                                ]
                                            ], 
                                        weighted_combination = {
                                            'key' : 1.337
                                            }, ), 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), 
                                simulated = aliro_quantum.models.results_data.ResultsData(
                                    empirical_sso = 1.337, 
                                    end_datetime = '0', 
                                    runtime = 1.337, 
                                    start_datetime = '0', ), ), ), 
                        id = '0', 
                        reservation = aliro_quantum.models.reservation.Reservation(
                            end_datetime = '0', 
                            id = '0', 
                            price = 1.337, 
                            start_datetime = '0', 
                            their_id = '0', ), 
                        target = aliro_quantum.models.owner_details.OwnerDetails(
                            owners = {
                                'key' : aliro_quantum.models.owner_details_owners.OwnerDetails_owners(
                                    devices = {
                                        'key' : aliro_quantum.models.device_details.DeviceDetails(
                                            active_reset_fidelity = 1.337, 
                                            depth_one_circuit_time = 1.337, 
                                            device_id = '0', 
                                            display_name = '0', 
                                            gate_info = aliro_quantum.models.device_details_gate_info.DeviceDetails_gateInfo(
                                                averages = {
                                                    'key' : aliro_quantum.models.device_details_gate_info_averages.DeviceDetails_gateInfo_averages(
                                                        current = 1.337, 
                                                        fidelity_change_per_day = 1.337, )
                                                    }, 
                                                gate_list = [
                                                    aliro_quantum.models.gate.Gate(
                                                        aliro_computed = True, 
                                                        fidelity = 1.337, 
                                                        fidelity_change_per_day = 1.337, 
                                                        qubit_from = aliro_quantum.models.qubit.Qubit(
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, 
                                                            t1 = 1.337, 
                                                            t2 = 1.337, ), 
                                                        qubit_to = aliro_quantum.models.qubit.Qubit(
                                                            name = 56, 
                                                            pos_x = 1.337, 
                                                            pos_y = 1.337, 
                                                            real_qubit = 56, 
                                                            t1 = 1.337, 
                                                            t2 = 1.337, ), 
                                                        gate_type = '0', )
                                                    ], ), 
                                            gates = [
                                                aliro_quantum.models.gate.Gate(
                                                    aliro_computed = True, 
                                                    fidelity = 1.337, 
                                                    fidelity_change_per_day = 1.337, 
                                                    gate_type = '0', )
                                                ], 
                                            initialization_time = 1.337, 
                                            is_simulator = True, 
                                            jobs_queue_size = 56, 
                                            last_calibration = '0', 
                                            max_shots = 56, 
                                            next_available_time = '0', 
                                            price = 1.337, 
                                            quantum_volume = 56, 
                                            qubits = {
                                                'key' : aliro_quantum.models.qubit.Qubit(
                                                    name = 56, 
                                                    pos_x = 1.337, 
                                                    pos_y = 1.337, 
                                                    real_qubit = 56, 
                                                    t1 = 1.337, 
                                                    t2 = 1.337, )
                                                }, 
                                            supports_mid_circuit_measurement = True, 
                                            t1 = 1.337, 
                                            t2 = 1.337, )
                                        }, )
                                }, ), )
                    ],
                language = '0',
        )

    def testCircuit(self):
        """Test Circuit"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 2.20.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from setuptools import setup, find_packages  # noqa: H301
from os import path

NAME = "aliro-quantum"
VERSION = "2.20.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md')) as f:
    long_description = f.read()

REQUIRES = [
    "certifi",
    "python-dateutil",
    "six >= 1.10",
    "sseclient-py >= 1.7",
    "urllib3 >= 1.15"
]

setup(
    name=NAME,
    version=VERSION,
    description="Aliro Quantum App",
    author="OpenAPI Generator community",
    author_email="nick@aliroquantum.com",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "Aliro Quantum App"],
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description=long_description,
    long_description_content_type='text/markdown'
)



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from aliro_quantum.configuration import Configuration


class DeviceDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'active_reset_fidelity': 'float',
        'depth_one_circuit_time': 'float',
        'device_id': 'str',
        'display_name': 'str',
        'gate_info': 'DeviceDetailsGateInfo',
        'gates': 'list[Gate]',
        'initialization_time': 'float',
        'is_simulator': 'bool',
        'jobs_queue_size': 'int',
        'last_calibration': 'str',
        'max_shots': 'int',
        'next_available_time': 'str',
        'price': 'float',
        'quantum_volume': 'int',
        'qubits': 'dict(str, Qubit)',
        'supports_mid_circuit_measurement': 'bool',
        't1': 'float',
        't2': 'float'
    }

    attribute_map = {
        'active_reset_fidelity': 'activeResetFidelity',
        'depth_one_circuit_time': 'depthOneCircuitTime',
        'device_id': 'deviceId',
        'display_name': 'displayName',
        'gate_info': 'gateInfo',
        'gates': 'gates',
        'initialization_time': 'initializationTime',
        'is_simulator': 'isSimulator',
        'jobs_queue_size': 'jobsQueueSize',
        'last_calibration': 'lastCalibration',
        'max_shots': 'maxShots',
        'next_available_time': 'nextAvailableTime',
        'price': 'price',
        'quantum_volume': 'quantumVolume',
        'qubits': 'qubits',
        'supports_mid_circuit_measurement': 'supportsMidCircuitMeasurement',
        't1': 't1',
        't2': 't2'
    }

    def __init__(self, active_reset_fidelity=None, depth_one_circuit_time=None, device_id=None, display_name=None, gate_info=None, gates=None, initialization_time=None, is_simulator=None, jobs_queue_size=None, last_calibration=None, max_shots=None, next_available_time=None, price=None, quantum_volume=None, qubits=None, supports_mid_circuit_measurement=None, t1=None, t2=None, local_vars_configuration=None):  # noqa: E501
        """DeviceDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._active_reset_fidelity = None
        self._depth_one_circuit_time = None
        self._device_id = None
        self._display_name = None
        self._gate_info = None
        self._gates = None
        self._initialization_time = None
        self._is_simulator = None
        self._jobs_queue_size = None
        self._last_calibration = None
        self._max_shots = None
        self._next_available_time = None
        self._price = None
        self._quantum_volume = None
        self._qubits = None
        self._supports_mid_circuit_measurement = None
        self._t1 = None
        self._t2 = None
        self.discriminator = None

        if active_reset_fidelity is not None:
            self.active_reset_fidelity = active_reset_fidelity
        if depth_one_circuit_time is not None:
            self.depth_one_circuit_time = depth_one_circuit_time
        if device_id is not None:
            self.device_id = device_id
        if display_name is not None:
            self.display_name = display_name
        if gate_info is not None:
            self.gate_info = gate_info
        if gates is not None:
            self.gates = gates
        if initialization_time is not None:
            self.initialization_time = initialization_time
        if is_simulator is not None:
            self.is_simulator = is_simulator
        if jobs_queue_size is not None:
            self.jobs_queue_size = jobs_queue_size
        if last_calibration is not None:
            self.last_calibration = last_calibration
        if max_shots is not None:
            self.max_shots = max_shots
        if next_available_time is not None:
            self.next_available_time = next_available_time
        if price is not None:
            self.price = price
        if quantum_volume is not None:
            self.quantum_volume = quantum_volume
        if qubits is not None:
            self.qubits = qubits
        if supports_mid_circuit_measurement is not None:
            self.supports_mid_circuit_measurement = supports_mid_circuit_measurement
        if t1 is not None:
            self.t1 = t1
        if t2 is not None:
            self.t2 = t2

    @property
    def active_reset_fidelity(self):
        """Gets the active_reset_fidelity of this DeviceDetails.  # noqa: E501


        :return: The active_reset_fidelity of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._active_reset_fidelity

    @active_reset_fidelity.setter
    def active_reset_fidelity(self, active_reset_fidelity):
        """Sets the active_reset_fidelity of this DeviceDetails.


        :param active_reset_fidelity: The active_reset_fidelity of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._active_reset_fidelity = active_reset_fidelity

    @property
    def depth_one_circuit_time(self):
        """Gets the depth_one_circuit_time of this DeviceDetails.  # noqa: E501


        :return: The depth_one_circuit_time of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._depth_one_circuit_time

    @depth_one_circuit_time.setter
    def depth_one_circuit_time(self, depth_one_circuit_time):
        """Sets the depth_one_circuit_time of this DeviceDetails.


        :param depth_one_circuit_time: The depth_one_circuit_time of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._depth_one_circuit_time = depth_one_circuit_time

    @property
    def device_id(self):
        """Gets the device_id of this DeviceDetails.  # noqa: E501


        :return: The device_id of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._device_id

    @device_id.setter
    def device_id(self, device_id):
        """Sets the device_id of this DeviceDetails.


        :param device_id: The device_id of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._device_id = device_id

    @property
    def display_name(self):
        """Gets the display_name of this DeviceDetails.  # noqa: E501


        :return: The display_name of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this DeviceDetails.


        :param display_name: The display_name of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._display_name = display_name

    @property
    def gate_info(self):
        """Gets the gate_info of this DeviceDetails.  # noqa: E501


        :return: The gate_info of this DeviceDetails.  # noqa: E501
        :rtype: DeviceDetailsGateInfo
        """
        return self._gate_info

    @gate_info.setter
    def gate_info(self, gate_info):
        """Sets the gate_info of this DeviceDetails.


        :param gate_info: The gate_info of this DeviceDetails.  # noqa: E501
        :type: DeviceDetailsGateInfo
        """

        self._gate_info = gate_info

    @property
    def gates(self):
        """Gets the gates of this DeviceDetails.  # noqa: E501


        :return: The gates of this DeviceDetails.  # noqa: E501
        :rtype: list[Gate]
        """
        return self._gates

    @gates.setter
    def gates(self, gates):
        """Sets the gates of this DeviceDetails.


        :param gates: The gates of this DeviceDetails.  # noqa: E501
        :type: list[Gate]
        """

        self._gates = gates

    @property
    def initialization_time(self):
        """Gets the initialization_time of this DeviceDetails.  # noqa: E501


        :return: The initialization_time of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._initialization_time

    @initialization_time.setter
    def initialization_time(self, initialization_time):
        """Sets the initialization_time of this DeviceDetails.


        :param initialization_time: The initialization_time of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._initialization_time = initialization_time

    @property
    def is_simulator(self):
        """Gets the is_simulator of this DeviceDetails.  # noqa: E501


        :return: The is_simulator of this DeviceDetails.  # noqa: E501
        :rtype: bool
        """
        return self._is_simulator

    @is_simulator.setter
    def is_simulator(self, is_simulator):
        """Sets the is_simulator of this DeviceDetails.


        :param is_simulator: The is_simulator of this DeviceDetails.  # noqa: E501
        :type: bool
        """

        self._is_simulator = is_simulator

    @property
    def jobs_queue_size(self):
        """Gets the jobs_queue_size of this DeviceDetails.  # noqa: E501


        :return: The jobs_queue_size of this DeviceDetails.  # noqa: E501
        :rtype: int
        """
        return self._jobs_queue_size

    @jobs_queue_size.setter
    def jobs_queue_size(self, jobs_queue_size):
        """Sets the jobs_queue_size of this DeviceDetails.


        :param jobs_queue_size: The jobs_queue_size of this DeviceDetails.  # noqa: E501
        :type: int
        """

        self._jobs_queue_size = jobs_queue_size

    @property
    def last_calibration(self):
        """Gets the last_calibration of this DeviceDetails.  # noqa: E501


        :return: The last_calibration of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._last_calibration

    @last_calibration.setter
    def last_calibration(self, last_calibration):
        """Sets the last_calibration of this DeviceDetails.


        :param last_calibration: The last_calibration of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._last_calibration = last_calibration

    @property
    def max_shots(self):
        """Gets the max_shots of this DeviceDetails.  # noqa: E501


        :return: The max_shots of this DeviceDetails.  # noqa: E501
        :rtype: int
        """
        return self._max_shots

    @max_shots.setter
    def max_shots(self, max_shots):
        """Sets the max_shots of this DeviceDetails.


        :param max_shots: The max_shots of this DeviceDetails.  # noqa: E501
        :type: int
        """

        self._max_shots = max_shots

    @property
    def next_available_time(self):
        """Gets the next_available_time of this DeviceDetails.  # noqa: E501


        :return: The next_available_time of this DeviceDetails.  # noqa: E501
        :rtype: str
        """
        return self._next_available_time

    @next_available_time.setter
    def next_available_time(self, next_available_time):
        """Sets the next_available_time of this DeviceDetails.


        :param next_available_time: The next_available_time of this DeviceDetails.  # noqa: E501
        :type: str
        """

        self._next_available_time = next_available_time

    @property
    def price(self):
        """Gets the price of this DeviceDetails.  # noqa: E501


        :return: The price of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this DeviceDetails.


        :param price: The price of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._price = price

    @property
    def quantum_volume(self):
        """Gets the quantum_volume of this DeviceDetails.  # noqa: E501


        :return: The quantum_volume of this DeviceDetails.  # noqa: E501
        :rtype: int
        """
        return self._quantum_volume

    @quantum_volume.setter
    def quantum_volume(self, quantum_volume):
        """Sets the quantum_volume of this DeviceDetails.


        :param quantum_volume: The quantum_volume of this DeviceDetails.  # noqa: E501
        :type: int
        """

        self._quantum_volume = quantum_volume

    @property
    def qubits(self):
        """Gets the qubits of this DeviceDetails.  # noqa: E501


        :return: The qubits of this DeviceDetails.  # noqa: E501
        :rtype: dict(str, Qubit)
        """
        return self._qubits

    @qubits.setter
    def qubits(self, qubits):
        """Sets the qubits of this DeviceDetails.


        :param qubits: The qubits of this DeviceDetails.  # noqa: E501
        :type: dict(str, Qubit)
        """

        self._qubits = qubits

    @property
    def supports_mid_circuit_measurement(self):
        """Gets the supports_mid_circuit_measurement of this DeviceDetails.  # noqa: E501


        :return: The supports_mid_circuit_measurement of this DeviceDetails.  # noqa: E501
        :rtype: bool
        """
        return self._supports_mid_circuit_measurement

    @supports_mid_circuit_measurement.setter
    def supports_mid_circuit_measurement(self, supports_mid_circuit_measurement):
        """Sets the supports_mid_circuit_measurement of this DeviceDetails.


        :param supports_mid_circuit_measurement: The supports_mid_circuit_measurement of this DeviceDetails.  # noqa: E501
        :type: bool
        """

        self._supports_mid_circuit_measurement = supports_mid_circuit_measurement

    @property
    def t1(self):
        """Gets the t1 of this DeviceDetails.  # noqa: E501


        :return: The t1 of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._t1

    @t1.setter
    def t1(self, t1):
        """Sets the t1 of this DeviceDetails.


        :param t1: The t1 of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._t1 = t1

    @property
    def t2(self):
        """Gets the t2 of this DeviceDetails.  # noqa: E501


        :return: The t2 of this DeviceDetails.  # noqa: E501
        :rtype: float
        """
        return self._t2

    @t2.setter
    def t2(self, t2):
        """Sets the t2 of this DeviceDetails.


        :param t2: The t2 of this DeviceDetails.  # noqa: E501
        :type: float
        """

        self._t2 = t2

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DeviceDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DeviceDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import aliro_quantum
from aliro_quantum.models.job_execution import JobExecution  # noqa: E501
from aliro_quantum.rest import ApiException

class TestJobExecution(unittest.TestCase):
    """JobExecution unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test JobExecution
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = aliro_quantum.models.job_execution.JobExecution()  # noqa: E501
        if include_optional :
            return JobExecution(
                parameters = aliro_quantum.models.execution_parameters.ExecutionParameters(
                    num_shots = 56, 
                    output_type = '0', ), 
                results = aliro_quantum.models.execution_results.ExecutionResults(
                    real = aliro_quantum.models.results_data.ResultsData(
                        empirical_sso = 1.337, 
                        end_datetime = '0', 
                        measurements = aliro_quantum.models.results_data_measurements.ResultsData_measurements(
                            raw = [
                                [
                                    [
                                        56
                                        ]
                                    ]
                                ], 
                            weighted_combination = {
                                'key' : 1.337
                                }, ), 
                        runtime = 1.337, 
                        start_datetime = '0', ), 
                    simulated = aliro_quantum.models.results_data.ResultsData(
                        empirical_sso = 1.337, 
                        end_datetime = '0', 
                        runtime = 1.337, 
                        start_datetime = '0', ), )
            )
        else :
            return JobExecution(
                parameters = aliro_quantum.models.execution_parameters.ExecutionParameters(
                    num_shots = 56, 
                    output_type = '0', ),
        )

    def testJobExecution(self):
        """Test JobExecution"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Aliro Quantum App

    This is an api for the Aliro Quantum App  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: nick@aliroquantum.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import aliro_quantum
from aliro_quantum.api.user_api import UserApi  # noqa: E501
from aliro_quantum.rest import ApiException


class TestUserApi(unittest.TestCase):
    """UserApi unit test stubs"""

    def setUp(self):
        self.api = aliro_quantum.api.user_api.UserApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_user_api_key_post(self):
        """Test case for user_api_key_post

        generate Aliro API key for user  # noqa: E501
        """
        pass

    def test_user_information_update_post(self):
        """Test case for user_information_update_post

        update user email and name  # noqa: E501
        """
        pass

    def test_user_password_change_post(self):
        """Test case for user_password_change_post

        change user password from known password  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
